==> vue-components-1.5.13.tgz: package/lib/buttons/src/Button.vue.rd.js <==
import { defineComponent as x, toRefs as z, computed as b, openBlock as l, createElementBlock as r, unref as o, normalizeClass as d, createVNode as y, createCommentVNode as u, renderSlot as i, createElementVNode as v } from "vue";
import "../../spinners/index.rd.js";
import { classes as k, overlay as $ } from "./buttonClasses.rd.js";
import { buttonProps as g } from "./buttonProps.rd.js";
import C from "../../spinners/src/Spinner.vue.rd.js";
const B = ["disabled"], N = {
  key: 1,
  class: ""
}, V = {
  class: "!w-max whitespace-nowrap inline-flex items-center flex-row",
  style: { color: "inherit" }
}, q = /* @__PURE__ */ x({
  __name: "Button",
  props: g(),
  setup(m) {
    const f = m, { customClass: c, type: h, press: w, color: a, loading: s, disabled: n, circle: t } = z(f), p = b(() => (n == null ? void 0 : n.value) || (s == null ? void 0 : s.value));
    return (e, E) => (l(), r("button", {
      disabled: o(p),
      class: d(["!font-bold press outline-none border-none relative select-none overflow-hidden w-max group inline-flex items-center justify-center !outline-none ring-0 rounded-md transition-all duration-100", [
        o(c),
        e.size,
        o(k)[o(h)][o(a)].class,
        o(w),
        {
          shadow: e.shadow,
          "pointer-events-none !opacity-80": o(p),
          "!w-full flex-center": e.block,
          "flex content-center px-2 rounded-lg": e.icon,
          "!rounded-full": e.rounded,
          "text-sm font-medium px-4 py-2 h-9": e.size == "default",
          "p-1 px-2 text-11px h-6": e.size == "xs",
          "p-2 text-12px h-8": e.size == "s",
          "p-4 text-12px h-10": e.size == "l",
          "p-5 text-13px h-12": e.size == "xl",
          "!rounded-full !p-0": o(t),
          "!max-w-11 !w-11 !max-h-11 !h-11": o(t) && e.size == "l",
          "!max-w-13 !w-13 !max-h-13 !h-13": o(t) && e.size == "xl",
          "!max-w-9 !w-9 !max-h-9 !h-9": o(t) && (e.size == "xs" || e.size == "s" || e.size == "default")
        }
      ]])
    }, [
      o(s) ? (l(), r("div", {
        key: 0,
        class: d([o($)[o(a)], "absolute top-0 left-0 w-full h-full text-white bg-opacity-80 z-10 flex-center"])
      }, [
        y(o(C), {
          inherit: !0,
          loading: !0
        })
      ], 2)) : u("", !0),
      e.$slots.prefix ? (l(), r("div", N, [
        i(e.$slots, "prefix")
      ])) : u("", !0),
      v("span", V, [
        i(e.$slots, "default")
      ]),
      i(e.$slots, "sufix")
    ], 10, B));
  }
});
export {
  q as default
};

==> vue-components-1.5.40.tgz: package/lib/buttons/src/Button.vue.rd.js <==
import { defineComponent as x, toRefs as z, computed as b, openBlock as l, createElementBlock as r, unref as o, normalizeClass as d, createVNode as y, createCommentVNode as u, renderSlot as i, createElementVNode as v } from "vue";
import "../../spinners/index.rd.js";
import { classes as k, overlay as $ } from "./buttonClasses.rd.js";
import { buttonProps as g } from "./buttonProps.rd.js";
import C from "../../spinners/src/Spinner.vue.rd.js";
const B = ["disabled"], N = {
  key: 1,
  class: ""
}, V = {
  class: "!w-max whitespace-nowrap inline-flex items-center flex-row",
  style: { color: "inherit" }
}, q = /* @__PURE__ */ x({
  __name: "Button",
  props: g(),
  setup(m) {
    const f = m, { customClass: c, type: h, press: w, color: a, loading: t, disabled: n, circle: s } = z(f), p = b(() => (n == null ? void 0 : n.value) || (t == null ? void 0 : t.value));
    return (e, E) => (l(), r("button", {
      disabled: o(p),
      class: d(["!font-bold press outline-none border-none relative select-none overflow-hidden group inline-flex items-center justify-center !outline-none ring-0 rounded-md transition-all duration-100", [
        o(c),
        e.size,
        o(k)[o(h)][o(a)].class,
        o(w),
        {
          shadow: e.shadow,
          "pointer-events-none !opacity-80": o(p),
          "!w-full flex-center": e.block,
          "flex content-center px-2 rounded-lg": e.icon,
          "!rounded-full": e.rounded,
          "text-sm font-medium px-4 py-2 h-9": e.size == "default",
          "p-1 px-2 text-11px h-6": e.size == "xs" && !o(s),
          "p-2 text-12px h-8": e.size == "s" && !o(s),
          "p-4 text-12px h-10": e.size == "l" && !o(s),
          "p-5 text-13px h-12": e.size == "xl" && !o(s),
          "!rounded-full !p-0": o(s),
          "max-w-11 w-11 max-h-11 h-11": o(s) && e.size == "l",
          "max-w-13 w-13 max-h-13 h-13": o(s) && e.size == "xl",
          "max-w-9 w-9 max-h-9 h-9": o(s) && (e.size == "xs" || e.size == "s" || e.size == "default")
        }
      ]])
    }, [
      o(t) ? (l(), r("div", {
        key: 0,
        class: d([o($)[o(a)], "absolute top-0 left-0 w-full h-full text-white bg-opacity-80 z-10 flex-center"])
      }, [
        y(o(C), {
          inherit: !0,
          loading: !0
        })
      ], 2)) : u("", !0),
      e.$slots.prefix ? (l(), r("div", N, [
        i(e.$slots, "prefix")
      ])) : u("", !0),
      v("span", V, [
        i(e.$slots, "default")
      ]),
      i(e.$slots, "sufix")
    ], 10, B));
  }
});
export {
  q as default
};
